﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using Microsoft.Extensions.Options;
using Platform.Uri;

namespace Platform.Sms
{
    /// <summary>
    /// Construct new clickatell service
    /// </summary>
    public class ClickatellService : ISmsService
    {
        private string _WebAddress;
        private string _Username;
        private string _Password;
        private string _ClientID;
        private string _ApiID;

        /// <summary>
        /// Construct new clickatell service
        /// </summary>
        /// <param name="settings"></param>
        public ClickatellService( IOptionsMonitor<ClickatellSettings> settings )
        {
            settings.OnChange(OnSettingsChanged);
            OnSettingsChanged(settings.CurrentValue, null);
        }

        private void OnSettingsChanged( ClickatellSettings settings, string name )
        {
            _WebAddress = settings.WebAddress;
            _Username = settings.Username;
            _Password = settings.Password;
            _ClientID = settings.ClientID;
            _ApiID = settings.ApiID;
        }

        /// <summary>
        /// Message Server
        /// </summary>
        /// <param name="number"></param>
        /// <param name="message"></param>
        /// <returns></returns>
        public async Task SendMessage(string number, string message)
        {
            NetUri uri = _WebAddress;
            uri.Query = new NetUriQuery();
            uri.Query["user"] = _Username;
            uri.Query["password"] = _Password;
            uri.Query["api_id"] = _ApiID;
            uri.Query["to"] = number;
            uri.Query["text"] = message;

            // create client
            var client = new HttpClient();
            var result = await client.GetAsync(uri.ToString());
            var content = await result.Content.ReadAsStringAsync();

            // do something with result
        }
    }
}
